@@ -1,4 +1,5 @@
 // Copyright (C) 2006-2014 David Sugar, Tycho Softworks.
+// Copyright (C) 2015 Cherokees of Idaho.
 //
 // This file is part of GNU uCommon C++.
 //
@@ -86,6 +87,9 @@ extern "C" int main()
     assert(eq(paste_test, "foobar"));
     assert(eq(paste_test_empty, "bar"));
 
+    assert(String::check("xxx", 3));
+    assert(!String::check("xxxx", 3));
+
     delete[] test;
     delete[] cdup;
 
